ProSHADE: Class Members

| ProSHADE 0.7.5.4 (MAR 2021) Protein Shape Detection

Here is a list of all documented class members with links to the class documentation for each member:

### - m -

- mapCOMProcessChangeX : ProSHADE_internal_data::ProSHADE_data
- mapCOMProcessChangeY : ProSHADE_internal_data::ProSHADE_data
- mapCOMProcessChangeZ : ProSHADE_internal_data::ProSHADE_data
- mapData() : ProSHADE_internal_spheres::ProSHADE_sphere
- mapMovFromsChangeX : ProSHADE_internal_data::ProSHADE_data
- mapMovFromsChangeY : ProSHADE_internal_data::ProSHADE_data
- mapMovFromsChangeZ : ProSHADE_internal_data::ProSHADE_data
- mapToSpheres() : ProSHADE_internal_data::ProSHADE_data
- maskFileName : ProSHADE_settings
- maskingThresholdIQRs : ProSHADE_settings
- maskMap() : ProSHADE_internal_data::ProSHADE_data , ProSHADE_settings
- maxBandwidth : ProSHADE_settings
- maxCompBand : ProSHADE_internal_data::ProSHADE_data
- maxShellBand : ProSHADE_internal_data::ProSHADE_data
- maxSphereDists : ProSHADE_settings
- maxSymmetryFold : ProSHADE_settings
- minSymPeak : ProSHADE_settings
- moveToCOM : ProSHADE_settings